==> hns2_2.19.5.orig.tar.gz: hns-2.19.5/hns-lite.sh <==
#!/bin/sh
# HyperNikkiSystem, hns-lite Creating Script for hns-2.10
# 2000/10/21 since 2000/05/04
# ChangeLog
# 2001-02-02     Yoichi Imai <yoichi@silver-forest.com>
#                * added changelog
#                * 0.7 release
#
# Copyright (C) 2000 Yoichi Imai <yoichi@silver-forest.com>
# $Id: hns-lite.sh,v 1.11 2002/04/04 10:54:57 kenji Exp $

LITE_VER=2.19.5
PATH=$PATH:/usr/sbin
PERL=/usr/local/bin/perl
SENDMAIL=/usr/sbin/sendmail
NKF=/usr/bin/nkf
LITE_DIR="/tmp/hns-lite-root/hns-lite-$LITE_VER"
#LITE_DIR_Q="\\/tmp\\/hns-lite-root\\/hns-lite-$LITE_VER"

mkdir /tmp/hns-lite-setup-$$
cp -pr . /tmp/hns-lite-setup-$$
cd /tmp/hns-lite-setup-$$

rm -rf /tmp/hns-lite-root
mkdir -p $LITE_DIR/hns-lite
mkdir -p $LITE_DIR/diary

make NIKKITITLE="Hoge's Nikki" \
     DIARYDIR="$LITE_DIR/diary" \
     HTMLDIR="$LITE_DIR/hns-lite" \
     PERL_PATH="$PERL" \
     SENDMAIL_PATH="$SENDMAIL" \
     NKF_PATH="$NKF" \
     MYDIARYURI="http://www.example.ne.jp/~hoge/hns-lite/" \
     install

cp -pr docs $LITE_DIR/docs.orig
cp GPL.txt $LITE_DIR/
cp GPL-j.txt $LITE_DIR/
cp README.ja $LITE_DIR/
# tar xvf hns-lite-doc.tar -C $LITE_DIR
cat > $LITE_DIR/INSTALL.txt <<EOF
󥹥ȡˤ,
EUCɤľԽǤ륨ǥ
FTPեȤɬפǤ

EUCԽǤ륨ǥȤƤ
Ģ++(http://www.vector.co.jp/soft/win95/writing/se120980.html),
FTPեȤǤ,
FFFTP(http://www.vector.co.jp/soft/win95/net/se061839.html)ޤ
ʤĢ++, FFFTP˥ե꡼եȥǤ

* 󥹥ȡˡ

1. եԽ
1.1 Խˡ
$ = "<<<Խʬ>>>";
<<<Խʬ>>>˻ꤵ줿Ƥꤷޤ

$Title : Υȥ
Ȼꤵ줿,
$Title = "Hoge's Diary";
ȤȤ
$Title = "Υȥ򤫤ޤ";
Ȥ褦˥ǥԽޤ
ȤʤʸΤդɬפǤ

1.2 Խս
hns-lite/config.ph
  $Title :  Υȥ
  $UserMail :  ᡼륢ɥ쥹
  $Author :  ʤ̾
  $MyDiaryURI :  åץɤȤˤǤǤhns-liteեURI
               Ȥ, http://www.example.ne.jp/~username/cgi-bin/hns-lite/ʤɡ
               ºݤ˥ΤdiaryեǤϤʤhns-liteեʤΤ
               diary/ ǤϤʤ, hns-lite/˥뤳Ȥˤʤޤ
hns-lite/i/config.ph
  $baseuri : $MyDiaryURIƱΤ
  $title : ȥ(i-mode)
  $head : ȥ(i-mode)
  $address : ᡼륢ɥ쥹

2. hns-liteեľäƤcgiե,
hns-liteեˤiեindex.cgi1ܤˤ
perlΥѥĶ˹碌ѹޤ
#!/usr/local/bin/perl
ɸǤƱʤѹɬפϤޤ

3. 
 hns-liteե
 diaryե
ftpեȤȤäžޤ
ξեˤ.htaccessȤե˺줺˥åץɤƤ
ʤ, 2ĤΥեƱ֤Ƥ

4. ѡߥåѹޤ
hns-lite/ *.cgi򤹤٤ : 755
hns-lite/i/index.cgi : 755
diary/   cacheե : 777
	 logե,βLM,OLD,lockե : 777
	 logΥե뤹٤ : 666
         data/boarddata.txt      : 666 (board.cgiѤ)

5. ؤΥ
ؤΥ󥯤
http://㥤󥹥ȡ뤷/hns-lite/
˹ԤäƤ

ǤȤޤϴλǤ
Ȥ, docs.origեäƤ,
http://www.h14m.org/ˤ򻲹ͤˤƤ
EOF
nkf -s $LITE_DIR/INSTALL.txt > $LITE_DIR/INSTALL.txt.out
mv $LITE_DIR/INSTALL.txt.out $LITE_DIR/INSTALL.txt

cat > $LITE_DIR/README-lite.txt <<EOF
HyperNikkiSystem Lite

HyperNikkiSystem Liteϡ
UnixȤΤ񤷤桼䡢
UnixĶѰդǤʤ桼󥹥ȡ뤷䤹褦
Hyper NIKKI SystemƥѥåΤǤ

(ơޤʤ)ȤʤʤäƤ뵡ǽե뤬ǽޤ
εǽѤˤ, Hyper NIKKI Systemꤹ뤫,
Hyper NIKKI SystemΤΤѤ

HyperNikkiSystem Project
http://www.h14m.org/hns-lite/
EOF
nkf -s $LITE_DIR/README-lite.txt > $LITE_DIR/README-lite.txt.out
mv $LITE_DIR/README-lite.txt.out $LITE_DIR/README-lite.txt

rm -rf /tmp/hns-lite-setup-$$
rm -rf $LITE_DIR/hns-lite/anti-windoze
rm -rf $LITE_DIR/hns-lite/ruribaka

cd $LITE_DIR/hns-lite
sed -e \
 "s|$LITE_DIR/diary/cache|\\\$DiaryDir/cache|g" \
    config.ph > config.ph.out
sed -e \
 "s|$LITE_DIR/|../|g" \
    config.ph.out > config.ph
sed -e \
 's|\.\./hns-lite|./|g' \
    config.ph > config.ph.out
mv config.ph.out config.ph

cd i/
sed -e \
 "s|$LITE_DIR/|../../|g" \
    config.ph > config.ph.out
sed -e \
 's|\.\./\.\./hns-lite/i|./|g' \
    config.ph.out > config.ph

rm config.ph.out
cp ../lib/jcode.pl .
cd ..

cd lib/HNS/
sed -e \
 's|\(print \"RURI[^\$]*\)\$HNS::System::|\1|g' \
    Admini.pm > Admini.pm.out
mv Admini.pm.out Admini.pm

cd $LITE_DIR/diary
cat > .htaccess <<EOF
<Limit GET POST PUT>
 deny from all
</Limit>
EOF

cd $LITE_DIR/hns-lite/lib

#CHANGE_BEFORE="^\\\$VERSION = \"\\(.*\\)\""
#CHANGE_AFTER="\\\$VERSION = \"\\1\\/hns-lite-$LITE_VER\""
sed -e \
 "s|\\(^\\\$VERSION .*\\)|\\1 \\\$LITE_VERSION = \"$LITE_VER\";|g" \
    HNS.pm > HNS.pm.out
mv HNS.pm.out HNS.pm

sed -e \
 's|\(^\$HnsHomePage .*\)|\1 \$HnsLiteHomePage = "http://www.h14m.org/hns-lite/";|g' \
    HNS.pm > HNS.pm.out
mv HNS.pm.out HNS.pm

sed -e \
 's|<a href="%s">hns-%s</a>|<a href="%s">hns-%s</a>/<a href="%s">hns-lite-%s</a>|g' \
    HNS.pm > HNS.pm.out
mv HNS.pm.out HNS.pm

sed -e \
 's|\(\$HnsHomePage, \$VERSION,\) \(\$HnsHomePage\)|\1 \$HnsLiteHomePage, \$LITE_VERSION, \2|g' \
    HNS.pm > HNS.pm.out
mv HNS.pm.out HNS.pm

sed -e \
 's|\(use vars qw.\)|\1\$LITE_VERSION \$HnsLiteHomePage |g' \
  HNS.pm > HNS.pm.out
mv HNS.pm.out HNS.pm

cd /tmp/hns-lite-root
tar zcf hns-lite-$LITE_VER.tar.gz hns-lite-$LITE_VER
lha c hns-lite-$LITE_VER.lzh hns-lite-$LITE_VER

==> hns-2.19.6.tar.gz: hns-2.19.6/hns-lite.sh <==
#!/bin/sh
# HyperNikkiSystem, hns-lite Creating Script for hns-2.10
# 2000/10/21 since 2000/05/04
# ChangeLog
# 2001-02-02     Yoichi Imai <yoichi@silver-forest.com>
#                * added changelog
#                * 0.7 release
#
# Copyright (C) 2000 Yoichi Imai <yoichi@silver-forest.com>
# $Id: hns-lite.sh,v 1.13 2003/01/03 10:26:52 bonaim Exp $

set -e

LITE_VER=`sed -ne 's/^\$VERSION = "\(.*\)";$/\1/p' public_html/diary/lib/HNS.pm`
PATH=$PATH:/usr/sbin
PERL=/usr/local/bin/perl
SENDMAIL=/usr/sbin/sendmail
NKF=/usr/bin/nkf
LITE_DIR="/tmp/hns-lite-root/hns-lite-$LITE_VER"
#LITE_DIR_Q="\\/tmp\\/hns-lite-root\\/hns-lite-$LITE_VER"

mkdir /tmp/hns-lite-setup-$$
cp -pr . /tmp/hns-lite-setup-$$
cd /tmp/hns-lite-setup-$$

rm -rf /tmp/hns-lite-root
mkdir -p $LITE_DIR/hns-lite
mkdir -p $LITE_DIR/diary

make NIKKITITLE="Hoge's Nikki" \
     DIARYDIR="$LITE_DIR/diary" \
     HTMLDIR="$LITE_DIR/hns-lite" \
     PERL_PATH="$PERL" \
     SENDMAIL_PATH="$SENDMAIL" \
     NKF_PATH="$NKF" \
     MYDIARYURI="http://www.example.ne.jp/~hoge/hns-lite/" \
     install

cp -pr docs $LITE_DIR/docs.orig
cp GPL.txt $LITE_DIR/
cp GPL-j.txt $LITE_DIR/
cp README.ja $LITE_DIR/
# tar xvf hns-lite-doc.tar -C $LITE_DIR
cat > $LITE_DIR/INSTALL.txt <<EOF
󥹥ȡˤ,
EUCɤľԽǤ륨ǥ
FTPեȤɬפǤ

EUCԽǤ륨ǥȤƤ
Ģ++(http://www.vector.co.jp/soft/win95/writing/se120980.html),
FTPեȤǤ,
FFFTP(http://www.vector.co.jp/soft/win95/net/se061839.html)ޤ
ʤĢ++, FFFTP˥ե꡼եȥǤ

* 󥹥ȡˡ

1. եԽ
1.1 Խˡ
$ = "<<<Խʬ>>>";
<<<Խʬ>>>˻ꤵ줿Ƥꤷޤ

$Title : Υȥ
Ȼꤵ줿,
$Title = "Hoge's Diary";
ȤȤ
$Title = "Υȥ򤫤ޤ";
Ȥ褦˥ǥԽޤ
ȤʤʸΤդɬפǤ

1.2 Խս
hns-lite/config.ph
  $Title :  Υȥ
  $UserMail :  ᡼륢ɥ쥹
  $Author :  ʤ̾
  $MyDiaryURI :  åץɤȤˤǤǤhns-liteեURI
               Ȥ, http://www.example.ne.jp/~username/cgi-bin/hns-lite/ʤɡ
               ºݤ˥ΤdiaryեǤϤʤhns-liteեʤΤ
               diary/ ǤϤʤ, hns-lite/˥뤳Ȥˤʤޤ
hns-lite/i/config.ph
  $baseuri : $MyDiaryURIƱΤ
  $title : ȥ(i-mode)
  $head : ȥ(i-mode)
  $address : ᡼륢ɥ쥹

2. hns-liteեľäƤcgiե,
hns-liteեˤiեindex.cgi1ܤˤ
perlΥѥĶ˹碌ѹޤ
#!/usr/local/bin/perl
ɸǤƱʤѹɬפϤޤ

3. 
 hns-liteե
 diaryե
ftpեȤȤäžޤ
ξեˤ.htaccessȤե˺줺˥åץɤƤ
ʤ, 2ĤΥեƱ֤Ƥ

4. ѡߥåѹޤ
hns-lite/ *.cgi򤹤٤ : 755
hns-lite/i/index.cgi : 755
diary/   cacheե : 777
	 logե,βLM,OLD,lockե : 777
	 logΥե뤹٤ : 666
         data/boarddata.txt      : 666 (board.cgiѤ)

5. ؤΥ
ؤΥ󥯤
http://㥤󥹥ȡ뤷/hns-lite/
˹ԤäƤ

ǤȤޤϴλǤ
Ȥ, docs.origեäƤ,
http://www.h14m.org/ˤ򻲹ͤˤƤ
EOF
nkf -s $LITE_DIR/INSTALL.txt > $LITE_DIR/INSTALL.txt.out
mv $LITE_DIR/INSTALL.txt.out $LITE_DIR/INSTALL.txt

cat > $LITE_DIR/README-lite.txt <<EOF
HyperNikkiSystem Lite

HyperNikkiSystem Liteϡ
UnixȤΤ񤷤桼䡢
UnixĶѰդǤʤ桼󥹥ȡ뤷䤹褦
Hyper NIKKI SystemƥѥåΤǤ

(ơޤʤ)ȤʤʤäƤ뵡ǽե뤬ǽޤ
εǽѤˤ, Hyper NIKKI Systemꤹ뤫,
Hyper NIKKI SystemΤΤѤ

HyperNikkiSystem Project
http://www.h14m.org/hns-lite/
EOF
nkf -s $LITE_DIR/README-lite.txt > $LITE_DIR/README-lite.txt.out
mv $LITE_DIR/README-lite.txt.out $LITE_DIR/README-lite.txt

rm -rf /tmp/hns-lite-setup-$$
rm -rf $LITE_DIR/hns-lite/anti-windoze
rm -rf $LITE_DIR/hns-lite/ruribaka

cd $LITE_DIR/hns-lite
sed -e \
 "s|$LITE_DIR/|../|g" \
    config.ph > config.ph.out
sed -e \
 's|\.\./hns-lite|./|g' \
    config.ph.out > config.ph
rm config.ph.out

cd i/
sed -e \
 "s|$LITE_DIR/|../../|g" \
    config.ph > config.ph.out
sed -e \
 's|\.\./\.\./hns-lite/i|./|g' \
    config.ph.out > config.ph

rm config.ph.out
cp ../lib/jcode.pl .
cd ..

cd lib/HNS/
sed -e \
 's|\(print \"RURI[^\$]*\)\$HNS::System::|\1|g' \
    Admini.pm > Admini.pm.out
mv Admini.pm.out Admini.pm

cd $LITE_DIR/diary
cat > .htaccess <<EOF
<Limit GET POST PUT>
 deny from all
</Limit>
EOF

cd $LITE_DIR/hns-lite/lib

sed -e 's/<div align="right">Powered by <a href="%s">hns-%s/&-lite/' \
  HNS.pm > HNS.pm.out
mv HNS.pm.out HNS.pm

cd /tmp/hns-lite-root
tar zcf hns-lite-$LITE_VER.tar.gz hns-lite-$LITE_VER
lha c hns-lite-$LITE_VER.lzh hns-lite-$LITE_VER
